$(document).ready(function() { 
    // Set up the "select all" switch on submission page. Default to all
    // selected, handle toggling all selected/unselected. Update link text
    // to appropriate statement each time. We do this here so the page
    // degrades OK sans JS support.
    $('#submit_form').prepend('<span id="trigger-select-all" style="font-size: 10px;"><strong><a href="#">Deselect all</a></strong></span>');
    $('#submit_form').find(':checkbox').attr('checked', true);
    $('#trigger-select-all').toggle(
        function() {
            $('#submit_form').find(':checkbox').attr('checked', false);
            $('#submit_form a').replaceWith('<a href="#">Select all</a>');
            return false;
        },
        function() {
            $('#submit_form').find(':checkbox').attr('checked', true);
            $('#submit_form a').replaceWith('<a href="#">Deselect all</a>');
            return false;
        }
    );
}); 
